summaryrefslogtreecommitdiffstats
path: root/kdeui/klineeditdlg.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /kdeui/klineeditdlg.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/klineeditdlg.h')
-rw-r--r--kdeui/klineeditdlg.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kdeui/klineeditdlg.h b/kdeui/klineeditdlg.h
index e5d0d3302..1c0ab6b31 100644
--- a/kdeui/klineeditdlg.h
+++ b/kdeui/klineeditdlg.h
@@ -43,25 +43,25 @@ public:
* Create a dialog that asks for a single line of text. _value is
* the initial value of the line. _text appears as label on top of
* the entry box. If the internal line edit has an associated
* QValidator set, the OK button is disabled as long as the
* validator doesn't return Acceptable. If there's no validator, the
* OK button is enabled whenever the line edit isn't empty.
*
* If you want to accept empty input, make a trivial QValidator that
* always returns Acceptable, e.g. QRegExpValidator with a
* regexp of ".*".
*
* @param _text Text of the label
* @param _value Initial value of the inputline
* @param parent Parent widget for the line edit dialog
*/
- KLineEditDlg( const QString& _text, const QString& _value, QWidget *parent ) KDE_DEPRECATED;
+ KLineEditDlg( const TQString& _text, const TQString& _value, TQWidget *parent ) KDE_DEPRECATED;
virtual ~KLineEditDlg();
/**
* @return the value the user entered
*/
- QString text() const;
+ TQString text() const;
/**
* @return the line edit widget
@@ -77,8 +77,8 @@ public:
* @param validator Validator to be stuffed into the line edit.
* @param parent The parent widget
*/
- static QString getText(const QString &text, const QString& value,
- bool *ok, QWidget *parent, QValidator *validator=0 ) KDE_DEPRECATED;
+ static TQString getText(const TQString &text, const TQString& value,
+ bool *ok, TQWidget *parent, TQValidator *validator=0 ) KDE_DEPRECATED;
/**
* Static convenience function to get a textual input from the user.
@@ -92,10 +92,10 @@ public:
* @param parent The parent widget for this text input dialog
* @param validator Validator to be stuffed into the line edit.
*/
- static QString getText(const QString &caption, const QString &text,
- const QString& value=QString::null,
- bool *ok=0, QWidget *parent=0,
- QValidator *validator=0) KDE_DEPRECATED;
+ static TQString getText(const TQString &caption, const TQString &text,
+ const TQString& value=TQString::null,
+ bool *ok=0, TQWidget *parent=0,
+ TQValidator *validator=0) KDE_DEPRECATED;
public slots:
/**
@@ -106,9 +106,9 @@ public slots:
protected slots:
/**
* Enables and disables the OK button depending on the state
* returned by the lineedit's QValidator.
*/
- void slotTextChanged( const QString& );
+ void slotTextChanged( const TQString& );
protected:
/**
@@ -43,25 +43,25 @@ public:
* the initial value of the line. _text appears as label on top of
* the entry box. If the internal line edit has an associated
- * QValidator set, the OK button is disabled as long as the
+ * TQValidator set, the OK button is disabled as long as the
* validator doesn't return Acceptable. If there's no validator, the
* OK button is enabled whenever the line edit isn't empty.
@@ -43,25 +43,25 @@ public:
* OK button is enabled whenever the line edit isn't empty.
*
- * If you want to accept empty input, make a trivial QValidator that
- * always returns Acceptable, e.g. QRegExpValidator with a
+ * If you want to accept empty input, make a trivial TQValidator that
+ * always returns Acceptable, e.g. TQRegExpValidator with a
* regexp of ".*".
*
@@ -106,9 +106,9 @@ public slots:
/**
* Enables and disables the OK button depending on the state
- * returned by the lineedit's QValidator.
+ * returned by the lineedit's TQValidator.
*/